# Primod


Primod is a pre-processing tool for [iMOD Coupler](https://github.com/Deltares/imod_coupler).
Its usage is documented in the [iMOD Suite documentation](https://github.com/Deltares/imod_coupler).